"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchSintegra = void 0;
const formatting_1 = require("../helpers/formatting");
const puppeteerHelper_1 = require("../helpers/puppeteerHelper");
const setupPuppeteer_1 = require("../helpers/setupPuppeteer");
const estados_1 = __importDefault(require("../utils/estados"));
const utils_1 = require("../utils/utils");
const NEXT_PAGE_CODE_SELECTOR = "table.conteudoarea tbody tr:nth-of-type(3) td table tbody tr td b";
const RADIO_SELECTOR = "input[value='2']";
const INPUT_SELECTOR = "input#argumento";
const ERROR_TYPE1_SELECTOR = "table.conteudoarea tbody tr:nth-of-type(3) td table tbody tr:nth-of-type(2) td:nth-of-type(2)";
const ERROR_TYPE2_SELECTOR = "table.conteudoarea tbody tr:nth-of-type(3) td table tbody tr:nth-of-type(2) td b";
const FETCH_RESULT_BUTTON_SELECTOR = "input#btnConsultar";
const DETAIL_RESULT_BUTTON = "a.btnCFDF";
const getValueSelectorBy = (trNthOfType, tdNthOfType) => `div.conteudo div.alpha table.conteudoarea tbody tr:nth-of-type(${trNthOfType}) td:nth-of-type(${tdNthOfType})`;
async function fetchSintegra(cnpj) {
    const browser = await setupPuppeteer_1.setupBrowser();
    try {
        const page = await setupPuppeteer_1.setupPage(estados_1.default.DISTRITO_FEDERAL.url, browser);
        await setupInitialPart(page, cnpj);
        await page.waitFor(NEXT_PAGE_CODE_SELECTOR);
        const firstErr = await puppeteerHelper_1.extractText(page, ERROR_TYPE1_SELECTOR);
        if ((firstErr === null || firstErr === void 0 ? void 0 : firstErr.split(".")[0].trim()) === "NÃO CADASTRADO COMO CONTRIBUINTE ICMS") {
            throw new Error("Não foi cadastrado como contribuinte de ICMS");
        }
        const secondErr = await puppeteerHelper_1.extractText(page, ERROR_TYPE2_SELECTOR);
        if (secondErr === "CONTRIBUINTE NÃO CADASTRADO COMO CONTRIBUINTE DE ICMS.") {
            throw new Error("Não foi cadastrado como contribuinte de ICMS");
        }
        const situation = await puppeteerHelper_1.extractText(page, DETAIL_RESULT_BUTTON);
        if (situation === "ATIVO") {
            const detailButton = await page.waitFor(DETAIL_RESULT_BUTTON);
            await detailButton.click();
        }
        else {
            throw new Error("Cadastro desativado");
        }
        await page.waitForNavigation();
        const sintegra = await retrieveAndProcessValues(page);
        return buildData(sintegra);
    }
    catch (err) {
        throw err;
    }
    finally {
        await browser.close();
    }
}
exports.fetchSintegra = fetchSintegra;
async function setupInitialPart(page, cnpj) {
    const radioButton = await page.waitFor(RADIO_SELECTOR);
    await radioButton.click();
    const input = await page.waitFor(INPUT_SELECTOR);
    await input.type(cnpj);
    await page.click(FETCH_RESULT_BUTTON_SELECTOR);
}
async function retrieveAndProcessValues(page) {
    const cnpj = await puppeteerHelper_1.extractText(page, getValueSelectorBy(3, 2));
    const cfDf = await puppeteerHelper_1.extractText(page, getValueSelectorBy(3, 4));
    const razaoSocial = await puppeteerHelper_1.extractText(page, getValueSelectorBy(4, 2));
    const nomeFantasia = await puppeteerHelper_1.extractText(page, getValueSelectorBy(5, 2));
    const logradouro = await puppeteerHelper_1.extractText(page, getValueSelectorBy(7, 2));
    const numero = await puppeteerHelper_1.extractText(page, getValueSelectorBy(8, 2));
    const complemento = await puppeteerHelper_1.extractText(page, getValueSelectorBy(8, 4));
    const bairro = await puppeteerHelper_1.extractText(page, getValueSelectorBy(9, 2));
    const municipio = await puppeteerHelper_1.extractText(page, getValueSelectorBy(10, 2));
    const uf = await puppeteerHelper_1.extractText(page, getValueSelectorBy(10, 4));
    const cep = await puppeteerHelper_1.extractText(page, getValueSelectorBy(11, 2));
    const telefone = await puppeteerHelper_1.extractText(page, getValueSelectorBy(11, 4));
    const atividadePrincipal = await puppeteerHelper_1.extractText(page, `${getValueSelectorBy(13, 2)} div`);
    const atividadeSecundaria = await puppeteerHelper_1.extractText(page, `${getValueSelectorBy(14, 2)} div`);
    const regimeDeApuracao = await puppeteerHelper_1.extractText(page, getValueSelectorBy(15, 2));
    const situacaoCadastral = await puppeteerHelper_1.extractText(page, getValueSelectorBy(16, 2));
    const dataDessaSituacaoCadastral = await puppeteerHelper_1.extractText(page, getValueSelectorBy(17, 2));
    const situacaoSintegra = await puppeteerHelper_1.extractText(page, getValueSelectorBy(18, 2));
    const result = {
        cnpj,
        cfDf,
        uf,
        razaoSocial,
        nomeFantasia,
        logradouro,
        numero,
        complemento,
        bairro,
        municipio,
        cep,
        telefone,
        atividadePrincipal: formatting_1.formatText(atividadePrincipal),
        atividadeSecundaria: formatting_1.formatText(atividadeSecundaria),
        regimeDeApuracao,
        situacaoCadastral,
        dataDessaSituacaoCadastral,
        situacaoSintegra,
    };
    return result;
}
function buildData(data) {
    if (utils_1.isObjectEmpty(data)) {
        throw new Error("Sem dados");
    }
    return {
        identificacao: {
            cnpj: data.cnpj,
            cfDf: data.cfDf,
            razaoSocial: data.razaoSocial,
            nomeFantasia: data.nomeFantasia,
        },
        endereco: {
            logradouro: data.logradouro,
            numero: data.numero,
            complemento: data.complemento,
            bairro: data.bairro,
            municipio: data.municipio,
            uf: data.uf,
            cep: data.cep,
            telefone: data.telefone,
        },
        informacoesComplementares: {
            atividadePrincipal: data.atividadePrincipal,
            atividadeSecundaria: data.atividadeSecundaria,
            regimeDeApuracao: data.regimeDeApuracao,
            situacaoCadastral: data.situacaoCadastral,
            dataDessaSituacaoCadastral: data.dataDessaSituacaoCadastral,
            situacaoSintegra: data.situacaoSintegra,
        },
    };
}
//# sourceMappingURL=sintegraDF.js.map